@@ -100,12 +100,8 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
     if ( alpha && saw_period && width == 0 )
 	Perl_croak(aTHX_ "Invalid version format (misplaced _ in number)");
 
-    if ( saw_period > 1 && qv == 0) {
+    if ( saw_period > 1 )
 	qv = 1; /* force quoted version processing */
-	if(ckWARN(WARN_SYNTAX))
-	    Perl_warner(aTHX_ packWARN(WARN_SYNTAX), 
-	    "v-string without leading 'v' deprecated for version objects");
-    }
 
     last = pos;
     pos = s;
@@ -393,7 +389,9 @@ Perl_upg_version(pTHX_ SV *ver, bool qv)
 #ifndef SvVOK
 #  if PERL_VERSION > 5
 	/* This will only be executed for 5.6.0 - 5.8.0 inclusive */
-	if ( len == 3 && !instr(version,".") && !instr(version,"_") ) {
+	if ( len >= 3 && !instr(version,".") && !instr(version,"_")
+	    && !(*version == 'u' && strEQ(version, "undef"))
+	    && (*version < '0' || *version > '9') ) {
 	    /* may be a v-string */
 	    SV * const nsv = sv_newmortal();
 	    const char *nver;
@@ -411,7 +409,7 @@ Perl_upg_version(pTHX_ SV *ver, bool qv)
 	    }
 
 	    /* is definitely a v-string */
-	    if ( saw_period == 2 ) {	
+	    if ( saw_period >= 2 ) {	
 		Safefree(version);
 		version = nver;
 	    }
